<?php

/**
 * OpenKM, Open Document Management System (http://www.openkm.com)
 * Copyright (c) 2006-2014 Paco Avila & Josep Llort
 * 
 * No bytes were intentionally harmed during the development of this application.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

namespace openkm;

use openkm\bean\Document;
use openkm\bean\Folder;
use openkm\bean\Mail;
use openkm\bean\Record;
use openkm\bean\QueryParams;
use openkm\impl\AuthImpl;
use openkm\impl\DocumentImpl;
use openkm\impl\FolderImpl;
use openkm\impl\MailImpl;
use openkm\impl\NoteImpl;
use openkm\impl\PropertyGroupImpl;
use openkm\impl\PropertyImpl;
use openkm\impl\RepositoryImpl;
use openkm\impl\SearchImpl;
use openkm\OKMWebservices;
use openkm\impl\RecordImpl;
use openkm\impl\RelationImpl;

/**
 * OKMWebservice20
 *
 * @author sochoa
 */
class OKMWebservice20 implements OKMWebservices {

    private $authImpl;
    private $docImpl;
    private $fldImpl;
    private $mailImpl;
    private $noteImpl;
    private $propertyGroupImpl;
    private $respositoryImpl;
    private $searchImpl;
    private $propertyImpl;
    private $recordImpl;
    private $relationImpl;

    public function __construct($host, $user, $password) {
        $this->authImpl = new AuthImpl($host, $user, $password);
        $this->docImpl = new DocumentImpl($host, $user, $password);
        $this->fldImpl = new FolderImpl($host, $user, $password);
        $this->mailImpl = new MailImpl($host, $user, $password);
        $this->noteImpl = new NoteImpl($host, $user, $password);
        $this->propertyGroupImpl = new PropertyGroupImpl($host, $user, $password);
        $this->propertyImpl = new PropertyImpl($host, $user, $password);
        $this->respositoryImpl = new RepositoryImpl($host, $user, $password);
        $this->searchImpl = new SearchImpl($host, $user, $password);
        $this->recordImpl = new RecordImpl($host, $user, $password);
        $this->relationImpl = new RecordImpl($host, $user, $password);
    }

    /**
     * getGrantedRoles
     */
    public function getGrantedRoles($nodeId) {
        return $this->authImpl->getGrantedRoles($nodeId);
    }

    /**
     * getGrantedUsers
     */
    public function getGrantedUsers($nodeId) {
        return $this->authImpl->getGrantedUsers($nodeId);
    }

    /**
     * getMail
     */
    public function getMail($user) {
        return $this->authImpl->getMail($user);
    }

    /**
     * getName
     */
    public function getName($user) {
        return $this->authImpl->getName($user);
    }

    /**
     * getRoles
     */
    public function getRoles() {
        return $this->authImpl->getRoles();
    }

    /**
     * getRolesByUser
     */
    public function getRolesByUser($user) {
        return $this->authImpl->getRolesByUser($user);
    }

    /**
     * getUsers
     */
    public function getUsers() {
        return $this->authImpl->getUsers();
    }

    /**
     * getUsersByRole
     */
    public function getUsersByRole($role) {
        return $this->authImpl->getUsersByRole($role);
    }

    /**
     * revokeRole
     */
    public function revokeRole($nodeId, $role, $permissions, $recursive) {
        $this->authImpl->revokeRole($nodeId, $role, $permissions, $recursive);
    }

    /**
     * revokeUser
     */
    public function revokeUser($nodeId, $user, $permissions, $recursive) {
        $this->authImpl->revokeUser($nodeId, $user, $permissions, $recursive);
    }

    /**
     * grantRole
     */
    public function grantRole($nodeId, $role, $permissions, $recursive) {
        $this->authImpl->grantRole($nodeId, $role, $permissions, $recursive);
    }

    /**
     * grantUser
     */
    public function grantUser($nodeId, $user, $permissions, $recursive) {
        $this->authImpl->grantUser($nodeId, $user, $permissions, $recursive);
    }

    /**
     * CreateDocument
     * @param \openkm\bean\Document $okmDocument
     * @param type $is
     * @return \openkm\bean\Document
     */
    public function createDocument(Document $document, $is) {
        return $this->docImpl->createDocument($document, $is);
    }

    /**
     * Create Document Simple
     * @param string $docPath The path of the Folder
     * @param byte $is recommend using file_get_contents — Reads entire file into a string
     * @return \openkm\bean\Document Document returns
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws IOException
     * @throws UnsupportMimeTypeException
     * @throws FileSizeExceededException
     * @throws UserQuotaExceededException
     * @throws VirusDetectedException
     * @throws ItemExistsException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws ExtensionException
     * @throws AutomationException
     * @throws UnknowException
     */
    public function createDocumentSimple($docPath, $is) {
        return $this->docImpl->createDocumentSimple($docPath, $is);
    }

    /**
     * Delete document
     * @param string $docId The uuid or path of the Document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws ExtensionException
     * @throws UnknowException
     */
    public function deleteDocument($docId) {
        $this->docImpl->deleteDocument($docId);
    }

    /**
     * Get document properties
     * @param string $docId The uuid or path of the Document
     * @return \openkm\bean\Document Document returns
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function getDocumentProperties($docId) {
        return $this->docImpl->getDocumentProperties($docId);
    }

    /**
     * Get content
     * @param string $docId The uuid or path of the Document
     * @return stream Content document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function getContent($docId) {
        return $this->docImpl->getContent($docId);
    }

    /**
     * Get content by version
     * @param string $docId The uuid or path of the Document
     * @param string $versionId the checksum of the Version the document
     * @return stream Content document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws IOException
     * @throws UnknowException
     */
    public function getContentByVersion($docId, $versionId) {
        return $this->docImpl->getContentByVersion($docId, $versionId);
    }

    /**
     * Get extracted text
     * @param type $docId The uuid or path of the Document
     * @return string Extracted text the Document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws IOException
     * @throws UnknowException
     */
    public function getExtractedText($docId) {
        return $this->docImpl->getExtractedText($docId);
    }

    /**
     * Get thumbnail
     * @param string $docId The uuid or path of the Document
     * @param string $type Use \openkm\util\ConverterHelper for the types
     * @return image/png Thumbnail document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws ConversionException
     * @throws IOException
     * @throws AutomationException
     * @throws UnknowException
     */
    public function getThumbnail($docId, $type) {
        return $this->docImpl->getThumbnail($docId, $type);
    }

    /**
     * get Document children
     * @param string $fldId The uuid or path of the Folder
     * @return array Returns an array of \openkm\bean\Document 
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function getDocumentChildren($fldId) {
        return $this->docImpl->getDocumentChildren($fldId);
    }

    /**
     * Rename document
     * @param string $docId The uuid or path of the Document
     * @param string $newName The new name for the Document
     * @return \openkm\bean\Document Document returns
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws ItemExistsException
     * @throws UnknowException
     */
    public function renameDocument($docId, $newName) {
        return $this->docImpl->renameDocument($docId, $newName);
    }

    /**
     * Set properties Document
     * @param \openkm\bean\Document $document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws VersionException
     * @throws UnknowException
     */
    public function setProperties(Document $okmDocument) {
        $this->docImpl->setProperties($okmDocument);
    }

    /**
     * Set Language
     * @param string $docId The uuid or path of the Document
     * @param string $lang The language in the following format (es,en,pt,de)
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws VersionException
     * @throws LockException
     * @throws UnknowException
     */
    public function setLanguage($docId, $lang) {
        $this->docImpl->setLanguage($docId, $lang);
    }

    /**
     * Set document title
     * @param string $docId The uuid or path of the Document
     * @param string $title The title Document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws VersionException
     * @throws LockException
     * @throws UnknowException
     */
    public function setTitle($docId, $title) {
        $this->docImpl->setTitle($docId, $title);
    }

    /**
     * Checkout
     * @param string $docId The uuid or path of the Document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws UnknowException
     */
    public function checkout($docId) {
        $this->docImpl->checkout($docId);
    }

    /**
     * Cancel checkout
     * @param string $docId The uuid or path of the Document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws UnknowException
     */
    public function cancelCheckout($docId) {
        $this->docImpl->cancelCheckout($docId);
    }

    /**
     * Force cancel checkout
     * @param string $docId The uuid or path of the Document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws PrincipalAdapterException
     * @throws UnknowException
     */
    public function forceCancelCheckout($docId) {
        $this->docImpl->forceCancelCheckout($docId);
    }

    /**
     * Is checkedOut
     * @param string $docId The uuid or path of the Document
     * @return boolean is checked out
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function isCheckedOut($docId) {
        return $this->docImpl->isCheckedOut($docId);
    }

    /**
     * Checkin
     * @param string $docId The uuid or path of the Document
     * @param file $is recommend using file_get_contents — Reads entire file into a string
     * @param string $comment The comment for the new version the document
     * @return \openkm\bean\Version Version returns
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws IOException
     * @throws FileSizeExceededException
     * @throws UserQuotaExceededException
     * @throws VirusDetectedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws ExtensionException
     * @throws AutomationException
     * @throws LockException
     * @throws UnknowException
     */
    public function checkin($docId, $is, $comment) {
        return $this->docImpl->checkin($docId, $is, $comment);
    }

    /**
     * Get Version History
     * @param string $docId The uuid or path of the Document
     * @return array Returns an array of \openkm\bean\Version
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function getVersionHistory($docId) {
        return $this->docImpl->getVersionHistory($docId);
    }

    /**
     * Lock
     * @param string $docId The uuid or path of the Document
     * @return \openkm\bean\LockInfo LockInfo returns
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function lock($docId) {
        return $this->docImpl->lock($docId);
    }

    /**
     * Unlock
     * @param string $docId The uuid or path of the Document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws UnknowException
     */
    public function unlock($docId) {
        $this->docImpl->unlock($docId);
    }

    /**
     * Force unlock
     * @param string $docId The uuid or path of the Document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException     
     * @throws UnknowException
     */
    public function forceUnlock($docId) {
        $this->docImpl->forceUnlock($docId);
    }

    /**
     * Is locked
     * @param string $docId The uuid or path of the Document
     * @return boolean is locked the Document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function isLocked($docId) {
        return $this->docImpl->isLocked($docId);
    }

    /**
     * Get lock info
     * @param string $docId The uuid or path of the Document
     * @return \openkm\bean\LockInfo LockInfo returns
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws UnknowException
     */
    public function getLockInfo($docId) {
        return $this->docImpl->getLockInfo($docId);
    }

    /**
     * Purge Document
     * @param string $docId The uuid or path of the Document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws ExtensionException
     * @throws UnknowException
     */
    public function purgeDocument($docId) {
        $this->docImpl->purgeDocument($docId);
    }

    /**
     * Move Document
     * @param string $docId The uuid or path of the Document
     * @param string $dstId The uuid or path of the Folder
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws ExtensionException
     * @throws ItemExistsException
     * @throws AutomationException
     * @throws UnknowException
     */
    public function moveDocument($docId, $dstId) {
        $this->docImpl->moveDocument($docId, $dstId);
    }

    /**
     * Copy Document
     * @param string $docId The uuid or path of the Document
     * @param string $dstId The uuid or path of the Folder
     * @param string $newName The new name for the Document
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws ExtensionException
     * @throws ItemExistsException
     * @throws AutomationException
     * @throws IOException
     * @throws UnknowException
     */
    public function copyDocument($docId, $dstId, $newName) {
        $this->docImpl->copyDocument($docId, $dstId, $newName);
    }

    /**
     * restoreVersion
     */
    public function restoreVersion($docId, $versionId) {
        $this->docImpl->restoreVersion($docId, $versionId);
    }

    /**
     * purgeVersionHistory
     */
    public function purgeVersionHistory($docId) {
        $this->docImpl->purgeVersionHistory($docId);
    }

    /**
     * getVersionHistorySize
     */
    public function getVersionHistorySize($docId) {
        return $this->docImpl->getVersionHistorySize($docId);
    }

    /**
     * isValid
     */
    public function isValidDocument($docId) {
        return $this->docImpl->isValidDocument($docId);
    }

    /**
     * getPath
     */
    public function getDocumentPath($uuid) {
        return $this->docImpl->getDocumentPath($uuid);
    }

    /**
     * getDetectedLanguages
     */
    public Function getDetectedLanguages() {
        return $this->docImpl->getDetectedLanguages();
    }

    /**
     * extendedDocumentCopy 
     * @param string $docId uuid and path the Document
     * @param string $dstId uuid and path the Folder
     * @param string $name
     * @param boolean $categories
     * @param boolean $keywords
     * @param boolean $propertyGroups
     * @param boolean $notes
     * @param boolean $wiki
     */
    public function extendedDocumentCopy($docId, $dstId, $name, $categories, $keywords, $propertyGroups, $notes, $wiki) {
        $this->docImpl->extendedDocumetnCopy($docId, $dstId, $name, $categories, $keywords, $propertyGroups, $notes, $wiki);
    }

    /**
     * 
     * @param type $docId
     * @param type $dstId
     * @param type $language
     * @param type $categories
     * @param type $keywords
     * @param type $propertyGroups
     * @param type $notes
     * @param type $wiki
     * @param type $properties
     */
    public function createFromTemplateSimple($docId, $dstPath, $language, $categories, $keywords, $propertyGroups, $notes, $wiki, $properties = array()) {
        $this->docImpl->createFromTemplate($docId, $dstId, $language, $categories, $keywords, $propertyGroups, $notes, $wiki, $properties);
    }

    /**
     * Create folder
     * @param Folder $fld The variable path into the parameter fld, must be initializated. It indicates the folder path into OpenKM.
     * @return Folder Create a new folder and return as a result an object Folder.
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws ItemExistsException
     * @throws ExtensionException
     * @throws AutomationException
     * @throws UnknowException
     */
    public function createFolder(Folder $fld) {
        return $this->fldImpl->createFolder($fld);
    }

    /**
     * Create Folder Simple
     * @param string $fldPath Path of the Folder
     * @return Folder Create a new folder and return as a result an object Folder.
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws ItemExistsException
     * @throws ExtensionException
     * @throws AutomationException
     * @throws UnknowException
     */
    public function createFolderSimple($fldPath) {
        return $this->fldImpl->createFolderSimple($fldPath);
    }

    /**
     * Get the properties of the folder
     * @param string $fldId The uuid or path of the Folder
     * @return Folder $folder Return the folder properties
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function getFolderProperties($fldId) {
        return $this->fldImpl->getFolderProperties($fldId);
    }

    /**
     * Delete Folder
     * @param string $fldId The uuid or path of the Folder
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws UnknowException
     */
    public function deleteFolder($fldId) {
        $this->fldImpl->deleteFolder($fldId);
    }

    /**
     * Rename Folder
     * @param string $fldId The uuid or path of the Folder
     * @param string $newName The new name for the folder 
     * @return \openkm\bean\Folder 
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function renameFolder($fldId, $newName) {
        return $this->fldImpl->renameFolder($fldId, $newName);
    }

    /**
     * Move folder into some folder or record.
     * @param string $fldId The uuid or path of the Folder
     * @param string $dstId The uuid or path of the Folder
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws UnknowException
     */
    public function moveFolder($fldId, $dstId) {
        $this->fldImpl->moveFolder($fldId, $dstId);
    }

    /**
     * Get Folder Children
     * @param string $fldId The uuid or path of the Folder or Record node
     * @return array Return an array of all Folder their parent is fldId
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function getFolderChildren($fldId) {
        return $this->fldImpl->getFolderChildren($fldId);
    }

    /**
     * Is valid Folder
     * @param string $fldId the uuid or paht of the Folder
     * @return boolean Return a boolean that indicate if the node is a folder or not.
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function isValidFolder($fldId) {
        return $this->fldImpl->isValidFolder($fldId);
    }

    /**
     * Get Folder Path
     * @param string $uuid The uuid of de Folder
     * @return string Convert folder UUID to folder path.
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function getFolderPath($uuid) {
        return $this->fldImpl->getFolderPath($uuid);
    }

    /**
     * Copy a folder into some folder or record.
     * Only the security grants are copyed to destination, the metadata, keywords etc... of the folder are not copyed. 
     * See "extendedFolderCopy" method for this feature.
     * 
     * @param string $fldId The uuid or path of the Folder
     * @param string $dstId The uuid or path of the Folder or Record
     * @param string $newName The new name for the Folder. Value is null, folder will preservate the same name.
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws ItemExistsException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws AutomationException
     * @throws UserQuotaExceededException
     * @throws IOException
     * @throws UnknowException
     */
    public function copyFolder($fldId, $dstId, $newName) {
        $this->fldImpl->copyFolder($fldId, $dstId, $newName);
    }

    /**
     * Copy a folder with associated data into some folder or record.
     * 
     * By default only the binary data and the security grants, the metadata, keywords etc... of the folder are not copyed. 
     * 
     * Additional:
     * > When category paramater is true the original values of the categories will be copied.
     * > When keywords paramater is true the original values of the keywords will be copied.
     * > When propertyGroups paramater is true the original values of the metadata groups will be copied.
     * > When notes paramater is true the original values of the notes will be copied.
     * > When wiki paramater is true the original values of the wiki will be copied.
     * 
     * @param string $fldId The uuid or path of the Folder
     * @param string $dstId The uuid or path of the Folder or Record
     * @param boolean $categories
     * @param boolean $keywords
     * @param boolean $propertyGroups
     * @param boolean $notes
     * @param boolean $wiki
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws ItemExistsException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws AutomationException
     * @throws UserQuotaExceededException
     * @throws IOException
     * @throws UnknowException
     */
    public function extendedFolderCopy($fldId, $dstId, $categories, $keywords, $propertyGroups, $notes, $wiki) {
        $this->fldImpl->extendedFolderCopy($fldId, $dstId, $categories, $keywords, $propertyGroups, $notes, $wiki);
    }

    /**
     * The ContentInfo object retrives information about:
     * > The number of folders into.
     * > The number of documents into.
     * > The number of records into.
     * > The number of mails into.
     * > The size in bytes of all objects into the folder.                    
     * 
     * @param string $fldId The uuid or path of the Folder
     * @return ContentInfo Return and object ContentInfo with information about folder.
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function getContentInfo($fldId) {
        return $this->fldImpl->getContentInfo($fldId);
    }

    /**
    /**
     * Folder is definitely removed from repository.
     * 
     * Usually you will purge folders into /okm:trash/userId - the personal trash user locations - but is possible to directly purge any folder from the whole repository.
     * 
     * When a folder is purged only will be able to be restored from a previously repository backup. The purge action remove the folder definitely from the repository.
     * 
     * @param string $fldId The uuid or path of the Folder
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws UnknowException
     */
    public function purgeFolder($fldId) {
        $this->fldImpl->purgeFolder($fldId);
    }

    /**
     * Set the folder style.
     * @param string $fldId The uuid or path of the Folder
     * @param long $styleId The id of the style
     * @throws ConnectionErrorException 
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws VersionException
     * @throws UnknowException
     */
    public function setStyle($fldId, $styleId) {
        $this->fldImpl->setStyle($fldId, $styleId);
    }

    /**
     * createMail
     * @param \openkm\bean\Mail $mail
     * @return \openkm\bean\Mail
     */
    public function createMail(Mail $mail) {
        return $this->mailImpl->createMail($mail);
    }

    /**
     * getMailProperties
     * @param string $mailId uuid or path the mail
     * @return \openkm\bean\Mail
     */
    public function getMailProperties($mailId) {
        return $this->mailImpl->getMailProperties($mailId);
    }

    /**
     * deleteMail
     * @param type $mailId
     */
    public function deleteMail($mailId) {
        $this->mailImpl->deleteMail($mailId);
    }

    /**
     * renameMail
     * @param type $mailId
     * @param type $newName
     */
    public function renameMail($mailId, $newName) {
        $this->mailImpl->renameMail($mailId, $newName);
    }

    /**
     * moveMail
     * @param string $mailId 
     * @param string $dstId
     */
    public function moveMail($mailId, $dstId) {
        $this->mailImpl->moveMail($mailId, $dstId);
    }

    /**
     * getMailChildren
     * @param type $fldId
     * @return array return array the \openkm\bean\Mail
     */
    public function getMailChildren($fldId) {
        return $this->mailImpl->getMailChildren($fldId);
    }

    /**
     * isValidMail
     * @param type $mailId
     * @return type
     */
    public function isValidMail($mailId) {
        return $this->mailImpl->isValidMail($mailId);
    }

    /**
     * getMailPath
     * @param type $uuid
     * @return type
     */
    public function getMailPath($uuid) {
        return $this->mailImpl->getMailPath($uuid);
    }

    /**
     * createAttachment
     * @param type $mailId
     * @param type $docName
     * @param type $content
     * @return \openkm\bean\Document
     */
    public function createAttachment($mailId, $docName, $content) {
        return $this->mailImpl->createAttachment($mailId, $docName, $content);
    }

    /**
     * deleteAttachment
     * @param type $mailId
     * @param type $docId
     */
    public function deleteAttachment($mailId, $docId) {
        $this->mailImpl->deleteAttachment($mailId, $docId);
    }

    /**
     * getAttachments
     * @param type $mailId
     * @return array return an array the \openkm\bean\Document
     */
    public function getAttachments($mailId) {
        return $this->mailImpl->getAttachments($mailId);
    }

    /**
     * purgeMail
     * @param type $mailId
     */
    public function purgeMail($mailId) {
        $this->mailImpl->purgeMail($mailId);
    }

    /**
     * copyMail
     * @param string $mailId 
     * @param string $dstId
     */
    public function copyMail($mailId, $dstId) {
        $this->mailImpl->copyMail($mailId, $dstId);
    }

    /**
     * extendedMailCopy
     * @param type $mailId
     * @param type $dstId
     * @param type $categories
     * @param type $keywords
     * @param type $propertyGroups
     * @param type $notes
     * @param type $wiki
     */
    public function extendedMailCopy($mailId, $dstId, $categories, $keywords, $propertyGroups, $notes, $wiki) {
        $this->mailImpl->extendedMailCopy($mailId, $dstId, $categories, $keywords, $propertyGroups, $notes, $wiki);
    }

    /**
     * sendMailWithAttachments
     * @param type $recipients
     * @param type $subject
     * @param type $body
     * @param type $docsId
     * @param type $dstId
     */
    public function sendMailWithAttachments($subject, $body, $dstId, $recipients = array(), $docsId = array()) {
        $this->mailImpl->sendMailWithAttachments($subject, $body, $dstId, $recipients, $docsId);
    }

    /**
     * Add note to a node
     * @param string $nodeId The uuid or path of the document, folder, mail or record
     * @param string $text The text
     * @return Note Return an object Note.
     * @throws ConnectionErrorException
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws UnknowException
     */
    public function addNote($nodeId, $text) {
        return $this->noteImpl->addNote($nodeId, $text);
    }

    /**
     * Retrieves the note.
     * 
     * @param string $noteId The noteId is an UUID. The object Node have a variable named path, in that case the path contains an UUID.
     * @return Note Return un object Note.
     * @throws ConnectionErrorException
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws UnknowException
     */
    public function getNote($noteId) {
        return $this->noteImpl->getNote($noteId);
    }

    /**
     * Delete a note
     * 
     * @param string $noteId The noteId is an UUID. The object Node have a variable named path, in that case the path contains an UUID.
     * @throws ConnectionErrorException
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws UnknowException
     */
    public function deleteNote($noteId) {
        $this->noteImpl->deleteNote($noteId);
    }

    /**
     * Change the note text.
     * 
     * @param string $noteId The noteId is an UUID. The object Node have a variable named path, in that case the path contains an UUID.
     * @param string $text The text
     * @throws ConnectionErrorException
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws UnknowException
     */
    public function setNote($noteId, $text) {
        $this->noteImpl->setNote($noteId, $text);
    }

    /**
     * Retrieve a list of all notes of a node.
     * 
     * @param string $nodeId The uuid or path of the document, folder, mail or record
     * @return array Return an array of all notes of a node.
     * @throws ConnectionErrorException
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException     
     * @throws UnknowException
     */
    public function listNotes($nodeId) {
        return $this->noteImpl->listNotes($nodeId);
    }

    /**
     * addGroup
     */
    public function addGroup($nodeId, $grpName) {
        $this->propertyGroupImpl->addGroup($nodeId, $grpName);
    }

    /**
     * removeGroup
     */
    public function removeGroup($nodeId, $grpName) {
        $this->propertyGroupImpl->removeGroup($nodeId, $grpName);
    }

    /**
     * 
     * @param type $nodeId
     * @return type
     */
    public function getGroups($nodeId) {
        return $this->propertyGroupImpl->getGroups($nodeId);
    }

    /**
     * getAllGroups
     */
    public function getAllGroups() {
        return $this->propertyGroupImpl->getAllGroups();
    }

    /**
     * getPropertyGroupProperties
     */
    public function getPropertyGroupProperties($nodeId, $grpName) {
        return $this->propertyGroupImpl->getPropertyGroupProperties($nodeId, $grpName);
    }

    /**
     * getPropertyGroupForm
     */
    public function getPropertyGroupForm($grpName) {
        return $this->propertyGroupImpl->getPropertyGroupForm($grpName);
    }

    /**
     * setPropetyGroupProperties
     */
    public function setPropetyGroupProperties($nodeId, $grpName, $formElementList = array()) {
        $this->propertyGroupImpl->setPropetyGroupProperties($nodeId, $grpName, $formElementList);
    }

    /**
     * setPropertyGroupPropertiesSimple
     */
    public function setPropertyGroupPropertiesSimple($nodeId, $grpName, $properties = array()) {
        $this->propertyGroupImpl->setPropertyGroupPropertiesSimple($nodeId, $grpName, $properties);
    }

    /**
     * hasGroup
     */
    public function hasGroup($nodeId, $grpName) {
        return $this->propertyGroupImpl->hasGroup($nodeId, $grpName);
    }

    /**
     * getRegisteredDefinition
     */
    public function getRegisteredDefinition() {
        return $this->propertyGroupImpl->getRegisteredDefinition();
    }

    /**
     * getSuggestions
     * @param string $nodeId
     * @param string $grpName
     * @param string $propName
     * @return array Suggestions
     */
    public function getSuggestions($nodeId, $grpName, $propName) {
        return $this->propertyGroupImpl->getSuggestions($nodeId, $grpName, $propName);
    }

    /**
     * registerDefinition
     * @param type $pgDef
     */
    public function registerDefinition($pgDef) {
        $this->propertyGroupImpl->registerDefinition($pgDef);
    }

    /**
     * getRootFolder
     */
    public function getRootFolder() {
        return $this->respositoryImpl->getRootFolder();
    }

    /**
     * getTrashFolder
     */
    public function getTrashFolder() {
        return $this->respositoryImpl->getTrashFolder();
    }

    /**
     * getTrashFolderBase
     */
    public function getTrashFolderBase() {
        return $this->respositoryImpl->getTrashFolderBase();
    }

    /**
     * getTemplatesFolder
     */
    public function getTemplatesFolder() {
        return $this->respositoryImpl->getTemplatesFolder();
    }

    /**
     * getPersonalFolder
     */
    public function getPersonalFolder() {
        return $this->respositoryImpl->getPersonalFolder();
    }

    /**
     * getPersonalFolderBase
     */
    public function getPersonalFolderBase() {
        return $this->respositoryImpl->getPersonalFolderBase();
    }

    /**
     * getMailFolder
     */
    public function getMailFolder() {
        return $this->respositoryImpl->getMailFolder();
    }

    /**
     * getMailFolderBase
     */
    public function getMailFolderBase() {
        return $this->respositoryImpl->getMailFolderBase();
    }

    /**
     * getThesaurusFolder
     */
    public function getThesaurusFolder() {
        return $this->respositoryImpl->getThesaurusFolder();
    }

    /**
     * getCategoriesFolder
     */
    public function getCategoriesFolder() {
        return $this->respositoryImpl->getCategoriesFolder();
    }

    /**
     * purgeTrash
     */
    public function purgeTrash() {
        $this->respositoryImpl->purgeTrash();
    }

    /**
     * getUpdateMessage
     */
    public function getUpdateMessage() {
        return $this->respositoryImpl->getUpdateMessage();
    }

    /**
     * getRepositoryUuid
     */
    public function getRepositoryUuid() {
        return $this->respositoryImpl->getRepositoryUuid();
    }

    /**
     * hasNode
     */
    public function hasNode($nodeId) {
        return $this->respositoryImpl->hasNode($nodeId);
    }

    /**
     * getNodePath
     */
    public function getNodePath($uuid) {
        return $this->respositoryImpl->getNodePath($uuid);
    }

    /**
     * getNodeUuid
     */
    public function getNodeUuid($nodePath) {
        return $this->respositoryImpl->getNodeUuid($nodePath);
    }

    /**
     * Get App Version
     * @return AppVersion Return information about OpenKM version.
     * @throws ConnectionErrorException
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws UnknowException
     */
    public function getAppVersion() {
        return $this->respositoryImpl->getAppVersion();
    }

    /**
     * copyAttributes
     * @param type $nodeId
     * @param type $dstId
     * @param type $categories
     * @param type $keywords
     * @param type $propertyGroups
     * @param type $notes
     * @param type $wiki
     */
    public function copyAttributes($nodeId, $dstId, $categories, $keywords, $propertyGroups, $notes, $wiki) {
        $this->respositoryImpl->copyAttributes($nodeId, $dstId, $categories, $keywords, $propertyGroups, $notes, $wiki);
    }

    public function executeScript($query) {
        $this->respositoryImpl->executeScript($query);
    }

    public function executeSqlQuery($query) {
        $this->respositoryImpl->executeSqlQuery($query);
    }

    public function executeHqlQuery($query) {
        $this->respositoryImpl->executeHqlQuery($query);
    }

    public function getTranslations($lang, $module) {
        $this->respositoryImpl->getTranslations($lang, $module);
    }

    /**
     * findByContent
     */
    public function findByContent($content) {
        return $this->searchImpl->findByContent($content);
    }

    /**
     * findByName
     */
    public function findByName($name) {
        return $this->searchImpl->findByName($name);
    }

    /**
     * findByKeywords
     */
    public function findByKeywords($keywords = array()) {
        return $this->searchImpl->findByKeywords($keywords);
    }

    /**
     * find
     */
    public function find(QueryParams $queryParams) {
        return $this->searchImpl->find($queryParams);
    }

    /**
     * findPaginated
     */
    public function findPaginated(QueryParams $queryParams, $offset, $limit) {
        return $this->searchImpl->findPaginated($queryParams, $offset, $limit);
    }

    /**
     * findSimpleQueryPaginated
     */
    public function findSimpleQueryPaginated($statement, $offset, $limit) {
        return $this->searchImpl->findSimpleQueryPaginated($statement, $offset, $limit);
    }

    /**
     * findMoreLikeThis
     */
    public function findMoreLikeThis($uuid, $max) {
        return $this->searchImpl->findMoreLikeThis($uuid, $max);
    }

    /**
     * getKeywordMap
     */
    public function getKeywordMap($filter = array()) {
        return $this->searchImpl->getKeywordMap($filter);
    }

    /**
     * getCategorizedDocuments
     */
    public function getCategorizedDocuments($categoryId) {
        return $this->searchImpl->getCategorizedDocuments($categoryId);
    }

    /**
     * saveSearch
     */
    public function saveSearch(QueryParams $params) {
        return $this->searchImpl->saveSearch($params);
    }

    /**
     * updateSearch
     */
    public function updateSearch(QueryParams $params) {
        $this->searchImpl->updateSearch($params);
    }

    /**
     * getSearch
     */
    public function getSearch($qpId) {
        return $this->searchImpl->getSearch($qpId);
    }

    /**
     * getAllSearchs
     */
    public function getAllSearchs() {
        return $this->searchImpl->getAllSearchs();
    }

    /**
     * deleteSearch
     */
    public function deleteSearch($qpId) {
        $this->searchImpl->deleteSearch($qpId);
    }

    /**
     * Add Category
     * @param string $nodeId The uuid or path of the document, folder, mail or record
     * @param string $catId The uuid or path of de category folder
     * @throws ConnectionErrorException
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws VersionException
     * @throws UnknowException
     */
    public function addCategory($nodeId, $catId) {
        $this->propertyImpl->addCategory($nodeId, $catId);
    }

    /**
     * Remove Category
     * @param string $nodeId The uuid or path of the document, folder, mail or record
     * @param string $catId The uuid or path of de category folder
     * @throws ConnectionErrorException
     * @throws AccessDeniedException
     * @throws PathNotFoundException
     * @throws RepositoryException
     * @throws DatabaseException
     * @throws LockException
     * @throws VersionException
     * @throws UnknowException
     */
    public function removeCategory($nodeId, $catId) {
        $this->propertyImpl->removeCategory($nodeId, $catId);
    }

    /**
     * addKeyword
     */
    public function addKeyword($nodeId, $keyword) {
        $this->propertyImpl->addKeyword($nodeId, $keyword);
    }

    /**
     * removeKeyword
     */
    public function removeKeyword($nodeId, $keyword) {
        $this->propertyImpl->removeKeyword($nodeId, $keyword);
    }

    /**
     * setEncryption
     */
    public function setEncryption($nodeId, $cipherName) {
        $this->propertyImpl->setEncryption($nodeId, $cipherName);
    }

    /**
     * unsetEncryption
     */
    public function unsetEncryption($nodeId) {
        $this->propertyImpl->unsetEncryption($nodeId);
    }

    /**
     * setSigned
     */
    public function setSigned($nodeId, $signed) {
        $this->propertyImpl->setSigned($nodeId, $signed);
    }

    /**
     * createRecord 
     * @param \openkm\bean\Record $rec
     * @return \openkm\bean\Record 
     */
    public function createRecord(Record $rec) {
        return $this->recordImpl->createRecord($rec);
    }

    /**
     * getRecordProperties
     * @param type $recId
     * @return \openkm\bean\Record
     */
    public function getRecordProperties($recId) {
        return $this->recordImpl->getRecordProperties($recId);
    }

    /**
     * deleteRecord
     * @param type $recId
     */
    public function deleteRecord($recId) {
        $this->recordImpl->deleteRecord($recId);
    }

    /**
     * purgeRecord
     * @param type $recId
     */
    public function purgeRecord($recId) {
        $this->recordImpl->purgeRecord($recId);
    }

    /**
     * renameRecord
     * @param type $recId
     * @param type $newName
     */
    public function renameRecord($recId, $newName) {
        $this->recordImpl->renameRecord($recId, $newName);
    }

    /**
     * moveRecord
     * @param type $recId
     * @param type $dstId
     */
    public function moveRecord($recId, $dstId) {
        $this->recordImpl->moveRecord($recId, $dstId);
    }

    /**
     * copyRecord
     * @param type $recId
     * @param type $dstId
     */
    public function copyRecord($recId, $dstId) {
        $this->recordImpl->copyRecord($recId, $dstId);
    }

    /**
     * 
     * @param type $recId
     * @return type
     */
    public function isValidRecord($recId) {
        return $this->recordImpl->isValidRecord($recId);
    }

    /**
     * getRecordChildren
     * @param type $fldId
     * @return array return an array the \openkm\bean\Record
     */
    public function getRecordChildren($fldId) {
        return $this->recordImpl->getRecordChildren($fldId);
    }

    /**
     * lockRecord
     * @param type $recId
     * @return type
     */
    public function lockRecord($recId) {
        return $this->recordImpl->lockRecord($recId);
    }

    /**
     * unlockRecord
     * @param type $recId
     */
    public function unlockRecord($recId) {
        $this->recordImpl->unlockRecord($recId);
    }

    /**
     * forceUnlockRecord
     * @param type $recId
     */
    public function forceUnlockRecord($recId) {
        $this->recordImpl->forceUnlockRecord($recId);
    }

    /**
     * setRecordTitle
     * @param type $recId
     */
    public function setRecordTitle($recId) {
        $this->recordImpl->setRecordTitle($recId);
    }

    /**
     * getRecordPath
     * @param type $recId
     */
    public function getRecordPath($uuid) {
        $this->recordImpl->getRecordPath($uuid);
    }

}

?>
